@@ -50,17 +50,8 @@ def get_matching_s3_keys(bucket, prefix="", suffix=""):
     for obj in get_matching_s3_objects(bucket, prefix, suffix):
         yield obj["Key"]
 
-def get_obj_from_bucket(bucket, key):
-    """
-    Get an object from a bucket given its key.
-
-    :param bucket: Name of the S3 bucket.
-    :param key: Name of the Object key.
-    """
-    # TODO: try/catch look for errors here..
-    fileobj = s3client.get_object(
-        Bucket=bucket,
-        Key=key
-    )
-    # TODO: need to know if this returns a string...
-    return fileobj['Body'].read()
+def download_obj(bucket, key, destination):
+    obj = s3client.get_object(Bucket=bucket,Key=key)
+    data = obj['Body'].read()
+    f = open(f"{destination}/{key}", 'wb+')
+    f.write(data)
\ No newline at end of file
